<?php

namespace Drupal\ableplayer;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\Core\Render\RendererInterface;

/**
 * AblePlayerVideoFormatterHelper service.
 */
class AblePlayerVideoFormatterHelper {

  /**
   * The renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs an AblePlayerVideoFormatterHelper object.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer.
   */
  public function __construct(RendererInterface $renderer) {
    $this->renderer = $renderer;
  }

  /**
   * Attaches render arrays for fields providing video tracks.
   */
  public function attachTracksFromParentEntity(FieldableEntityInterface $parent, array &$elements) {
    if ($parent->hasField('ableplayer_caption')) {
      foreach ($elements as &$element) {
        $element['caption'] = $parent->ableplayer_caption->view(['type' => 'ableplayer_caption']);
      }
    }

    if ($parent->hasField('ableplayer_chapter')) {
      foreach ($elements as &$element) {
        $element['chapter'] = $parent->ableplayer_chapter->view(['type' => 'ableplayer_chapter']);
      }
    }

    if ($parent->hasField('ableplayer_poster_image')) {
      foreach ($elements as &$element) {
        $build = $parent->ableplayer_poster_image->view(['type' => 'ableplayer_poster_image']);
        $poster = $this->renderer->render($build);
        $element['#attributes']->setAttribute('poster', $poster);
      }
    }
  }

}
